@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.1.18
+# Version   : 0.1.20
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -407,8 +407,7 @@ class AFM:
         self.spr_const = float(_spr_const)
 
     def nanoscope_read(
-        self,
-        adjusted_tip_position = False
+        self
         ):
         '''
         Function to import raw force curve data
@@ -418,7 +417,7 @@ class AFM:
 
         self.approach_raw = np.zeros([self.samps_line, len(self.filelist)])
         self.retract_raw = np.zeros([self.samps_line, len(self.filelist)])
-        self.z_position_raw = np.zeros([self.samps_line * 2 , len(self.filelist)])
+        self.z_position_raw = np.zeros([self.samps_line , len(self.filelist)])
 
         for filename in self.filelist:
 
@@ -429,17 +428,7 @@ class AFM:
             _retract_curve = np.fromfile(file = data, dtype = 'int16', count = self.samps_line) * self.zscale * self.spr_const * self.def_sens
 
             hscale = (self.zsens * self.ramp_size * 2 ** 16 / self.samps_line ) / 2
-            tip_position = hscale * np.arange(1, self.samps_line + 1)
-
-            if adjusted_tip_position is True:
-
-                _z_approach = tip_position + self.spr_const * _approach_curve
-                _z_retract = tip_position + self.spr_const * _retract_curve
-
-                _z_position = np.concatenate((_z_approach, _z_retract), axis=0)
-
-            else:
-                _z_position = np.concatenate((tip_position, tip_position), axis=0)
+            _z_position = hscale * np.arange(1, self.samps_line + 1)
 
             self.approach_raw[:,i] = np.array(_approach_curve)
             self.retract_raw[:,i] = np.array(_retract_curve)
@@ -456,8 +445,8 @@ class AFM:
         plot must be given as an input <.plot_raw(n)>
         '''
         fig = go.Figure()
-        fig.add_trace(go.Scatter(y = self.approach_raw[:,curve_number], x = self.z_position_raw[:,curve_number][0:int(self.samps_line/2)], mode='lines', name = 'Approach curve (raw)'))
-        fig.add_trace(go.Scatter(y = self.retract_raw[:,curve_number], x = self.z_position_raw[:,curve_number][int(self.samps_line/2):self.samps_line], mode='lines', name = 'Retract curve (raw)'))
+        fig.add_trace(go.Scatter(y = self.approach_raw[:,curve_number], x = self.z_position_raw[:,curve_number], mode='lines', name = 'Approach curve (raw)'))
+        fig.add_trace(go.Scatter(y = self.retract_raw[:,curve_number], x = self.z_position_raw[:,curve_number], mode='lines', name = 'Retract curve (raw)'))
         fig.update_layout(
             yaxis_title_text='Force (nN)',
             xaxis_title_text='Tip separation (nm)',
@@ -510,10 +499,12 @@ class AFM:
             approach_dev = np.std(_approach_region)
             retract_dev = np.std(_retract_region)
 
+            piezo_position = np.concatenate((_z, _z), axis = 0)
+
             if approach_dev < max_approach_noise and retract_dev < max_retract_noise:
                 self.approach[:,i] = adjusted_approach
                 self.retract[:,i] = adjusted_retract
-                self.z_position[:,i] = _z
+                self.z_position[:,i] = piezo_position
 
                 i += 1
 
@@ -550,6 +541,22 @@ class AFM:
             except:
                 print('WARNING: Could not locate contact point for curve number ', i, '. Consider checking baseline alignment.')
 
+    def adjust_tip_position(
+        self
+    ):
+
+        for i in range(0, self.z_position.shape[1]):
+
+            _z = self.z_position[:,i]
+            _approach = self.approach[:,i]
+            _retract = self.retract[:,i]
+                
+            tip_approach = _z[0:self.samps_line] + self.spr_const * _approach
+            tip_retract = _z[(self.samps_line + 1):(self.samps_line * 2)] + self.spr_const * _retract
+
+            tip_position = np.concatenate((tip_approach, tip_retract), axis = 0)
+
+            self.z_position[:,i] = tip_position
 
     def plot_adjusted(
         self,
@@ -560,8 +567,8 @@ class AFM:
         plot must be given as an input <.plot_adjusted(n)>
         '''
         fig = go.Figure()
-        fig.add_trace(go.Scatter(y = self.approach[:,curve_number], x = self.z_position[:,curve_number][0:int(self.samps_line/2)], mode='lines', name = 'Approach curve'))
-        fig.add_trace(go.Scatter(y = self.retract[:,curve_number], x = self.z_position[:,curve_number][int(self.samps_line/2):self.samps_line], mode='lines', name = 'Retract curve'))
+        fig.add_trace(go.Scatter(y = self.approach[:,curve_number], x = self.z_position[:,curve_number][0:self.samps_line], mode='lines', name = 'Approach curve'))
+        fig.add_trace(go.Scatter(y = self.retract[:,curve_number], x = self.z_position[:,curve_number][(self.samps_line + 1):(self.samps_line * 2)], mode='lines', name = 'Retract curve'))
         fig.update_layout(
             yaxis_title_text='Force (nN)',
             xaxis_title_text='Tip separation (nm)',
@@ -582,14 +589,14 @@ class AFM:
                         visible=False,
                         name= 'Approach ' + str(step),
                         y = self.approach[:, step],
-                        x = self.z_position[:, step][0:int(self.samps_line/2)]
+                        x = self.z_position[:, step][0:self.samps_line]
                     ))
 
             trace_2.append(go.Scatter(
                         visible=False,
                         name= 'Retract ' + str(step),
                         y = self.retract[:, step],
-                        x = self.z_position[:, step][int(self.samps_line/2):self.samps_line]
+                        x = self.z_position[:, step][(self.samps_line + 1):(self.samps_line * 2)]
                     ))
 
         fig = go.Figure(data = trace_1 + trace_2)
